@@ -16,8 +16,8 @@ use Net::OSCAR::Constants;
 use Net::OSCAR::Utility;
 
 use vars qw($VERSION $REVISION);
-$VERSION = '1.10';
-$REVISION = '$Revision: 1.32.6.11 $';
+$VERSION = '1.11';
+$REVISION = '$Revision: 1.32.6.13 $';
 
 sub init_entry($$$$) {
 	my($blinternal, $type, $gid, $bid) = @_;
@@ -116,15 +116,16 @@ sub BLI_to_NO($) {
 		$session->{groupperms} = 0xFFFFFFFF;
 	}
 
-	if(exists $bli->{4} and (my($presbid) = keys %{$bli->{5}->{0}})) {
+	if(exists $bli->{5} and (my($presbid) = keys %{$bli->{5}->{0}})) {
 		my $typedata = $bli->{5}->{0}->{$presbid}->{data};
 		($session->{showidle}) = unpack("N", $typedata->{0xC9} || pack("F", 0x0061E7FF));
 		($session->{presence_unknown}) = unpack("N", $typedata->{0xD6} || pack("F", 0x0077FFFF));
 		delete $typedata->{0xC9};
 		delete $typedata->{0xD6};
 	} else {
-		$session->{showidle} = 0x0061E7FF;
-		$session->{presence_unknown} = 0x0077FFFF;
+		# OSCAR complains if we set presence when it didn't give it to us...
+		#$session->{showidle} = 0x0061E7FF;
+		#$session->{presence_unknown} = 0x0077FFFF;
 	}
 
 	if(exists $bli->{0x14}) {
@@ -226,12 +227,14 @@ sub NO_to_BLI($) {
 		$bli->{4}->{0}->{$vistype}->{data}->{$appdata} = $session->{appdata}->{$appdata};
 	}
 
-	my $presencetype;
-	$presencetype = (keys %{$session->{blinternal}->{5}->{0}})[0] if exists($session->{blinternal}->{5}) and exists($session->{blinternal}->{5}->{0}) and scalar keys %{$session->{blinternal}->{5}->{0}};
-	$presencetype ||= 0x0001;
-	init_entry($bli, 5, 0, $presencetype);
-	$bli->{5}->{0}->{$presencetype}->{data}->{0xC9} = pack("N", exists($session->{showidle}) ? $session->{showidle} : 0x0061E7FF);
-	$bli->{5}->{0}->{$presencetype}->{data}->{0xD6} = pack("N", exists($session->{presence_unknown}) ? $session->{presence_unknown} : 0x0077FFFF);
+	if(exists($session->{showidle})) {
+		my $presencetype;
+		$presencetype = (keys %{$session->{blinternal}->{5}->{0}})[0] if exists($session->{blinternal}->{5}) and exists($session->{blinternal}->{5}->{0}) and scalar keys %{$session->{blinternal}->{5}->{0}};
+		$presencetype ||= 0x0001;
+		init_entry($bli, 5, 0, $presencetype);
+		$bli->{5}->{0}->{$presencetype}->{data}->{0xC9} = pack("N", exists($session->{showidle}) ? $session->{showidle} : 0x0061E7FF);
+		$bli->{5}->{0}->{$presencetype}->{data}->{0xD6} = pack("N", exists($session->{presence_unknown}) ? $session->{presence_unknown} : 0x0077FFFF);
+	}
 
 
 	if(exists($session->{icon_md5sum})) {
